.. _utilipy-data_utils:

*********************************
Data Utils (`utilipy.data_utils`)
*********************************

.. currentmodule:: utilipy.data_utils


Reference/API
=============

.. automodapi:: utilipy.data_utils


.. automodapi:: utilipy.data_utils.decorators
.. automodapi:: utilipy.data_utils.select
.. automodapi:: utilipy.data_utils.crossmatch


Submodules
----------

.. toctree::
	:maxdepth: 1

	fitting
	xfm
